@@ -88,6 +88,13 @@ class Request(Storage):
             web2py_uuid())
         return self.uuid
 
+    def user_agent(self):
+        from gluon.contrib import user_agent_parser
+        session = current.session
+        session._user_agent = session._user_agent or \
+            user_agent_parser.detect(self.env.http_user_agent)
+        return session._user_agent
+
     def restful(self):
         def wrapper(action,self=self):
             def f(_action=action,_self=self,*a,**b):
@@ -129,10 +136,11 @@ class Response(Storage):
         self.session_id = None
         self.cookies = Cookie.SimpleCookie()
         self.postprocessing = []
-        self.flash = ''           # used by the default view layout
-        self.meta = Storage()     # used by web2py_ajax.html
-        self.menu = []            # used by the default view layout
-        self.files = []           # used by web2py_ajax.html
+        self.flash = ''            # used by the default view layout
+        self.meta = Storage()      # used by web2py_ajax.html
+        self.menu = []             # used by the default view layout
+        self.files = []            # used by web2py_ajax.html
+        self.generic_patterns = [] # patterns to allow generic views
         self._vars = None
         self._caller = lambda f: f()
         self._view_environment = None
