@@ -19,6 +19,7 @@ import rewrite
 import itertools
 import decoder
 import copy_reg
+import cPickle
 import marshal
 from HTMLParser import HTMLParser
 from htmlentitydefs import name2codepoint
@@ -43,6 +44,7 @@ __all__ = [
     'BR',
     'BUTTON',
     'CENTER',
+    'CAT',
     'CODE',
     'DIV',
     'EM',
@@ -194,7 +196,7 @@ def URL(
     :raises SyntaxError: when a CRLF is found in the generated url
     """
 
-    args = args or []
+    if args in (None,[]): args = []
     vars = vars or {}
     application = None
     controller = None
@@ -270,10 +272,9 @@ def URL(
 
         sig = hmac_hash(message,hmac_key,salt=salt)
         # add the signature into vars
-        vars['_signature'] = sig
         list_vars.append(('_signature', sig))
 
-    if vars:
+    if list_vars:
         other += '?%s' % urllib.urlencode(list_vars)
     if anchor:
         other += '#' + urllib.quote(str(anchor))
@@ -996,6 +997,19 @@ class DIV(XmlComponent):
             return None
         return sibs[0]
 
+class CAT(DIV):
+    
+    tag = ''
+
+def TAG_unpickler(data):
+    return cPickle.loads(data)
+
+def TAG_pickler(data):
+    d = DIV()
+    d.__dict__ = data.__dict__
+    marshal_dump = cPickle.dumps(d)
+    return (TAG_unpickler, (marshal_dump,))
+
 class __TAG__(XmlComponent):
 
     """
@@ -1016,7 +1030,7 @@ class __TAG__(XmlComponent):
             name = name.encode('utf-8')
         class __tag__(DIV):
             tag = name
-
+        copy_reg.pickle(__tag__, TAG_pickler, TAG_unpickler)
         return lambda *a, **b: __tag__(*a, **b)
 
     def __call__(self,html):
@@ -1804,6 +1818,95 @@ class FORM(DIV):
             newform.append(hidden_fields)
         return DIV.xml(newform)
 
+    def validate(self, 
+                 values=None,
+                 session=None, 
+                 formname='default',
+                 keepvalues=False,
+                 onvalidation=None,
+                 hideerror=False,
+                 onsuccess='flash',
+                 onfailure='flash',
+                 message_onsuccess=None, 
+                 message_onfailure=None, 
+                 ):
+        """
+        This function validates the form, 
+        you can use it instead of directly form.accepts.
+
+        Usage:
+        In controller
+
+        def action():
+            form=FORM(INPUT(_name=\"test\", requires=IS_NOT_EMPTY()))
+            form.validate() #you can pass some args here - see below
+            return dict(form=form)
+
+        This can receive a bunch of arguments        
+
+        onsuccess = 'flash' - will show message_onsuccess in response.flash
+                    None - will do nothing
+                    can be a function (lambda form: pass)
+        onfailure = 'flash' - will show message_onfailure in response.flash
+                    None - will do nothing
+                    can be a function (lambda form: pass)
+
+        values = values to test the validation - dictionary, response.vars, session or other - Default to (request.vars, session)
+        message_onsuccess
+        message_onfailure
+        """
+        from gluon import current
+        if not session: session = current.session
+        if not values: values = current.request.post_vars
+         
+        message_onsuccess = message_onsuccess or current.T("Success!")
+        message_onfailure = message_onfailure or \
+            current.T("Errors in form, please check it out.")
+
+        if self.accepts(values, session):
+            if onsuccess == 'flash':
+                current.response.flash = message_onsuccess
+            elif callable(onsuccess):
+                onsuccess(self)
+            return True
+        elif self.errors:
+            if onfailure == 'flash':
+                current.response.flash = message_onfailure
+            elif callable(onfailure):
+                onfailure(self)
+            return False
+
+    def process(self, values=None, session=None, **args):
+        """
+        Perform the .validate() method but returns the form
+
+        Usage in controllers:
+        # directly on return
+        def action():
+            #some code here
+            return dict(form=FORM(...).process(...))
+
+        You can use it with FORM, SQLFORM or FORM based plugins
+
+        Examples:
+        #response.flash messages
+        def action():
+            form = SQLFORM(db.table).process(message_onsuccess='Sucess!')
+            retutn dict(form=form)
+
+        # callback function
+        # callback receives True or False as first arg, and a list of args.
+        def my_callback(status, msg):
+           response.flash = "Success! "+msg if status else "Errors occured"
+
+        # after argument can be 'flash' to response.flash messages
+        # or a function name to use as callback or None to do nothing.
+        def action():
+            return dict(form=SQLFORM(db.table).process(onsuccess=my_callback)
+        """ 
+        self.validate(values=values, session=session, **args)
+        return self
+
 
 class BEAUTIFY(DIV):
 
@@ -2077,7 +2180,7 @@ def markdown_serializer(text,tag=None,attr={}):
     return text
 
 def markmin_serializer(text,tag=None,attr={}):
-    if tag is None: return re.sub('\s+',' ',text)
+    # if tag is None: return re.sub('\s+',' ',text)
     if tag=='br': return '\n\n'
     if tag=='h1': return '# '+text+'\n\n'
     if tag=='h2': return '#'*2+' '+text+'\n\n'
@@ -2090,7 +2193,8 @@ def markmin_serializer(text,tag=None,attr={}):
     if tag in ['td','th']: return ' | '+text
     if tag in ['b','strong','label']: return '**%s**' % text
     if tag in ['em','i']: return "''%s''" % text
-    if tag in ['tt','code']: return '``%s``' % text
+    if tag in ['tt']: return '``%s``' % text.strip()
+    if tag in ['code']: return '``\n%s``' % text
     if tag=='a': return '[[%s %s]]' % (text,attr.get('_href',''))
     if tag=='img': return '[[%s %s left]]' % (attr.get('_alt','no title'),attr.get('_src',''))
     return text
