@@ -520,11 +520,12 @@ def wsgibase(environ, responder):
 
                     if response.flash and not 'web2py-component-flash' in http_response.headers:
                         http_response.headers['web2py-component-flash'] = \
-                            dumps(str(response.flash).replace('\n',''))
+                            str(response.flash).replace('\n','')
                     if response.js and not 'web2py-component-command' in http_response.headers:
                         http_response.headers['web2py-component-command'] = \
                             response.js.replace('\n','')
-                if session._forget:
+                if session._forget and \
+                        response.session_id_name in response.cookies:
                     del response.cookies[response.session_id_name]
                 elif session._secure:
                     response.cookies[response.session_id_name]['secure'] = True
@@ -584,11 +585,14 @@ def wsgibase(environ, responder):
 #             gluon.debug.stop_trace()
 
     session._unlock(response)
-    http_response = rewrite.try_redirect_on_error(http_response,request,ticket)
+    http_response, new_environ = rewrite.try_rewrite_on_error(
+        http_response, request, environ, ticket)
+    if not http_response:
+        return wsgibase(new_environ,responder)
     if global_settings.web2py_crontype == 'soft':
         newcron.softcron(global_settings.applications_parent).start()
     return http_response.to(responder)
-
+    
 
 def save_password(password, port):
     """
